@@ -130,12 +130,12 @@
     <message>
         <location filename="mainwindow.ui" line="354"/>
         <source>Show partitions</source>
-        <translation type="unfinished"/>
+        <translation>Näytä osiot</translation>
     </message>
     <message>
         <location filename="mainwindow.ui" line="361"/>
         <source>Show all devices</source>
-        <translation type="unfinished"/>
+        <translation>Näytä kaikki laitteet</translation>
     </message>
     <message>
         <location filename="mainwindow.cpp" line="181"/>
